module Seximal

export @b6_str
export yocte, zepte, atte, femte, pice, nane, micre, mille, cente, dice
export yotte, zette, exe, pete, tere, gige, mege, kile, hecte, dece

# Senary prefixes
function base6(number::AbstractString)
    if occursin('e', number)
        (digits, exponent) = split(number, 'e')
    else
        (digits, exponent) = (number, "0")
    end

    if occursin('.', digits)
        value = parse(BigFloat, digits, base=6)
    else
        value = parse(BigInt, digits, base=6)
    end

    expval = parse(Int, exponent, base=6)

    if expval < 0
        return 1 // (value * BigInt(6) ^ (-expval))
    else
        return value * BigInt(6) ^ expval
    end
end

macro b6_str(digits)
    value = base6(digits)

    return :( $value )
end

yocte = b6"1e-52" # y |
zepte = b6"1e-44" # z |
atte = b6"1e-40" # a  |
femte = b6"1e-32" # f |
pice = b6"1e-24" # p  |
nane = b6"1e-20" # n  |
micre = b6"1e-12" # μ |
mille = b6"1e-4" # m  |
cente = b6"1e-2" # c  |
dice = b6"1e-1" # d   |
dece = b6"1e1" # de   |
hecte = b6"1e2" # h   |
kile = b6"1e4" # k    |
mege = b6"1e12" # M   |
gige = b6"1e20" # G   |
tere = b6"1e24" # T   |
pete = b6"1e32" # P   |
exe = b6"1e40" # E    |
zette = b6"1e44" # Z  |
yotte = b6"1e52" # Y  |

end # module Seximal
